# Copyright 2024 Superlinked, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass

from beartype.typing import Generic

from superlinked.framework.common.dag.node import NodeDataT


@dataclass(frozen=True)
class QueryNodeInputValue(Generic[NodeDataT]):
    item: NodeDataT
    weight: float | dict[str, float]


@dataclass(frozen=True)
class QueryNodeInput(Generic[NodeDataT]):
    value: QueryNodeInputValue[NodeDataT]
    to_invert: bool
